Orange Bioinformatics
=====================

Orange Bioinformatics extends Orange_, a data mining software
package, with common functionality for bioinformatics. The provided
functionality can be accessed as a Python library or through a visual
programming interface (Orange Canvas). The latter is also suitable for
non-programmers.

In Orange Canvas the analyst connects basic computational units, called
widgets, into data flow analytics schemas. Two units-widgets can be
connected if they share a data type. Compared to other popular tools like
Taverna, Orange widgets are high-level, integrated potentially complex
tasks, but are specific enough to be used independently. Even elaborate
analyses rarely consist of more than ten widgets; while tasks such as
clustering and enrichment analysis could be executed with up to five
widgets. While building the schema each widget is independently controlled
with settings, the settings do not conceptually burden the analyst.

Orange Bioinformatics provides access to publicly available data,
like GEO data sets, Biomart, GO, KEGG, Atlas, ArrayExpress, and PIPAx
database. As for the analytics, there is gene selection, quality control,
scoring distances between experiments with multiple factors. All features
can be combined with powerful visualization, network exploration and
data mining techniques from the Orange data mining framework.

.. _Orange: http://orange.biolab.si/

Documentation: http://pythonhosted.org/Orange-Bioinformatics
